pub struct JsonCodec<D, E> { /* private fields */ }Trait Implementations
Sourceimpl<D, E> Decoder for JsonCodec<D, E>where
D: DeserializeOwned,
impl<D, E> Decoder for JsonCodec<D, E>where
D: DeserializeOwned,
Sourcefn decode(
&mut self,
src: &mut BytesMut,
) -> Result<Option<Self::Item>, Self::Error>
fn decode( &mut self, src: &mut BytesMut, ) -> Result<Option<Self::Item>, Self::Error>
Attempts to decode a frame from the provided buffer of bytes. Read more
fn decode_eof(
&mut self,
buf: &mut BytesMut,
) -> Result<Option<Self::Item>, Self::Error>
fn decode_eof( &mut self, buf: &mut BytesMut, ) -> Result<Option<Self::Item>, Self::Error>
A default method available to be called when there are no more bytes
available to be read from the underlying I/O. Read more